@@ -1,12 +1,13 @@
 package Plack::HTTPParser;
 use strict;
-use base qw(Exporter);
+use parent qw(Exporter);
 
 our @EXPORT = qw( parse_http_request );
 
+use Try::Tiny;
+
 {
-    local $@;
-    if (!$ENV{PLACK_HTTP_PARSER_PP} && eval { require HTTP::Parser::XS; 1 }) {
+    if (!$ENV{PLACK_HTTP_PARSER_PP} && try { require HTTP::Parser::XS; 1 }) {
         *parse_http_request = \&HTTP::Parser::XS::parse_http_request;
     } else {
         require Plack::HTTPParser::PP;
