@@ -6,6 +6,13 @@ use URI::Escape ();
 
 use Plack::Util::Accessor qw/callback_key/;
 
+sub prepare_app {
+    my $self = shift;
+    unless (defined $self->callback_key) {
+        $self->callback_key('callback');
+    }
+}
+
 sub call {
     my($self, $env) = @_;
     my $res = $self->app->($env);
@@ -13,7 +20,7 @@ sub call {
         my $res = shift;
         if (defined $res->[2] && ref $res->[2] eq 'ARRAY' && @{$res->[2]} == 1) {
             my $h = Plack::Util::headers($res->[1]);
-            my $callback_key = quotemeta($self->callback_key) || 'callback';
+            my $callback_key = $self->callback_key;
             if ($h->get('Content-Type') =~ m!/(?:json|javascript)! &&
                 $env->{QUERY_STRING} =~ /(?:^|&)$callback_key=([^&]+)/) {
                 my $cb = URI::Escape::uri_unescape($1);
